/*
 * ServletConfig.java -- Interface for classes holding initialization data
 *                       to be passed from server to servlet
 *
 * Copyright (c) 1998, 1999 by Free Software Foundation, Inc.
 * Written by Paul Siegmann (pauls@euronet.nl)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as published
 * by the Free Software Foundation, version 2. (see COPYING.LIB)
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA
 */

package javax.servlet;

import java.util.Enumeration;


/**
 * Whenever a server wants to pass initialization data to a servlet, it
 * creates a class which implements this interface.<BR>
 * The server then adds {String,String} pairs to the class, and the servlet
 * can read these using this interface.
 *
#ifdef SERVLET_2_0
 * @version Servlet API 2.0 
#endif
#ifdef SERVLET_2_1
 * @version Servlet API 2.1
#endif
#ifdef SERVLET_2_2
 * @version Servlet API 2.2
#endif
 * @since Servlet API 1.0
 * @author Paul Siegmann (pauls@euronet.nl)
 */
public interface ServletConfig
{
	/**
	 * Get the value of this name's initparameter 
	 *
	 * @since Servlet API 1.0
	 *
	 * @param name the name of the Parameter whose value we want
	 * @return The value of this name's initparameter or null if it doesn't
	 * exist
	 */
	String getInitParameter (String name);


	/**
	 * Get all InitParameterNames
	 *
	 * @since Servlet API 1.0
	 *
	 * @return An enumeration consisting of all the init parameter names
	 * or an empty empty enumeration when there are no init parameters
	 */
	Enumeration getInitParameterNames ();


	/**
	 * Get the context of this ServletConfig
	 *
	 * @since Servlet API 1.0
	 *
	 * @return The context of the servlet whose Config this is
	 */
	ServletContext getServletContext ();

#ifdef SERVLET_2_2

	/**
	 * XXX
	 */
	String getServletName();
#endif
}
