/*
 * TagData.java
 * 
 * Copyright (c) 1999 by Free Software Foundation, Inc.
 * Written by Wes Biggs (wes@cacas.org)
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as published
 * by the Free Software Foundation, version 2. (see COPYING.LIB)
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation  
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA
 */

package javax.servlet.jsp.tagext;

import java.util.Hashtable;

/**
 * Represents the request-time parameters for a JSP tag.
 * The distinguished object <code>REQUEST_TIME_VALUE</code> can be
 * used to indicate whether a particular named attribute is static
 * or depends on recomputation during each request.
 */
public class TagData implements Cloneable {
    private Hashtable attributes;
    public static final Object REQUEST_TIME_VALUE = new Object();
    
    public TagData(Object[][] atts) {
	attributes = new Hashtable();
	if (atts != null) {
	    for (int i = 0; i < atts.length; i++) {
		attributes.put(atts[i][0],atts[i][1]);
	    }
	}
    }

    public String getId() {
	return (String) attributes.get(TagAttributeInfo.ID);
    }

    public Object getAttribute(String attName) {
	return attributes.get(attName);
    }

    public String getAttributeString(String attName) {
	return (String) attributes.get(attName);
    }

    public void setAttribute(String attName, Object value) {
	attributes.put(attName, value);
    }
}
