/*
 * TagLibraryInfo.java
 * 
 * Copyright (c) 1999 by Free Software Foundation, Inc.
 * Written by Wes Biggs (wes@cacas.org)
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as published
 * by the Free Software Foundation, version 2. (see COPYING.LIB)
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation  
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA
 */

package javax.servlet.jsp.tagext;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.Vector;
import org.openxml.parser.*;
import org.w3c.dom.*;

public class TagLibraryInfo {
    private String prefix;
    protected InputStream tldis;
    private URL uri;
    private String version;
    private String jspVersion;
    private String shortName;
    private String urn;
    private String info;
    private Vector tags;

    public TagLibraryInfo(String prefix, URL uri, InputStream tldis) {
	this.prefix = prefix;
	this.uri = uri;
	this.tldis = tldis;
	tags = new Vector();

	// Parse the InputStream as a TLD document.
	// Uses openXML.
	XMLParser parser = new XMLParser(new InputStreamReader(tldis),null);
	try {
	    Document doc = parser.parseDocument();
	    parseTLD(doc.getDocumentElement().getFirstChild());
	} catch (ParseException e) {
	    // Barring a real exception handling mechanism...
	    System.err.println(e);
	}
    }

    private void parseTLD(Node e) {
	if (e == null) return;
	if (e instanceof Element) {
	    String tagName = ((Element) e).getTagName();
	    if (tagName.equals("version")) {
		version = getBodyText(e);
	    } else if (tagName.equals("jspversion")) {
		jspVersion = getBodyText(e);
	    } else if (tagName.equals("shortname")) {
		shortName  = getBodyText(e);
	    } else if (tagName.equals("urn")) {
		urn = getBodyText(e);
	    } else if (tagName.equals("info")) {
		info = getBodyText(e);
	    } else if (tagName.equals("tag")) {
		TagInfo ti = parseTag(e.getFirstChild());
		tags.addElement(ti);
	    }
	}
	parseTLD(e.getNextSibling());
    }

    private TagInfo parseTag(Node t) {
	String name = null;
	String tagclass = null;
	String teiclass = null;
	String bodycontent = null;
	String taginfo = null;
	Vector attributes = new Vector();
	String tagName;
	do {
	    if (t instanceof Element) {
		tagName = ((Element) t).getTagName();
		if (tagName.equals("name")) {
		    name = getBodyText(t);
		} else if (tagName.equals("tagclass")) {
		    tagclass = getBodyText(t);
		} else if (tagName.equals("teiclass")) {
		    teiclass = getBodyText(t);
		} else if (tagName.equals("bodycontent")) {
		    bodycontent = getBodyText(t);
		} else if (tagName.equals("info")) {
		    taginfo = getBodyText(t);
		} else if (tagName.equals("attribute")) {
		    attributes.addElement(parseAttribute(t.getFirstChild()));
		}
	    }
	} while ((t = t.getNextSibling()) != null);

	// Create TagInfo for values read.
	// Note: not yet dealing with TagExtraInfo (see the null)
	TagAttributeInfo[] tai = new TagAttributeInfo [attributes.size()];
	attributes.copyInto(tai);
	return new TagInfo(name, tagclass, bodycontent,
			   taginfo, this, null, tai);
    }

    private TagAttributeInfo parseAttribute(Node t) {
	String name = null;
	boolean required = false;
	boolean rtexprvalue = false;
	String type = "java.lang.String";
	String temp;
	String tagName;
	do {
	    if (t instanceof Element) {
		tagName = ((Element) t).getTagName();
		if (tagName.equals("name")) {
		    name = getBodyText(t);
		} else if (tagName.equals("required")) {
		    temp = getBodyText(t);
		    if (temp.equals("yes") || temp.equals("true"))
			required = true;
		} else if (tagName.equals("rtexprvalue")) {
		    temp = getBodyText(t);
		    if (temp.equals("yes") || temp.equals("true"))
			rtexprvalue = true;
		} else if (tagName.equals("type")) {
		    type = getBodyText(t);
		}
	    }
	} while ((t = t.getNextSibling()) != null);
	return new TagAttributeInfo(name, type, rtexprvalue);
    }

    private String getBodyText(Node e) {
	if (!e.hasChildNodes()) return null;
	return ((CharacterData) e.getFirstChild()).getData();
    }
    
    public String getPrefixString() {
	return prefix;
    }

    public String getShortName() {
	return shortName;
    }

    public String getReliableURN() {
	return urn;
    }

    public String getInfoString() {
	return info;
    }

    public String getRequiredVersion() { 
	return jspVersion;
    }

    public TagInfo getTag(String name) {
	TagInfo[] t = getTags();
	for (int i = 0; i < t.length; i++) {
	    if (t[i].getTagName().equals(name)) return t[i];
	}
	return null;
    }

    public TagInfo[] getTags() {
	TagInfo[] retval = new TagInfo [tags.size()];
	tags.copyInto(retval);
	return retval;
    }

    public URL getURI() {
	return uri;
    }
}
